#ifndef DSPOUTOSS_H_INCLUDED
#define DSPOUTOSS_H_INCLUDED

#include <sys/soundcard.h>
#include "dspout.h"

/**
 * @short OSS implementation of DspOut.
 * @author Billy Biggs <vektor@div8.net>
 *
 * This is the OSS implementation of DspOut for the /dev/dsp*
 * devices.  Note that you cannot change how many fragments
 * this class requests, yet.
 */
class DspOutOss : public DspOut
{
	Q_OBJECT //!
public:
	/**
	 * Constructs a DspOutOss object representing the given
	 * filename.  Default is /dev/dsp.
	 */
	DspOutOss( const QString &fileName = "/dev/dsp" );

	/**
	 * Destructor.  Will close the device if it is open.
	 */
	virtual ~DspOutOss( void );

	bool openDevice( DeviceMode mode );
	bool openDevice( int exist_fs );
	bool writeBuffer( void );
	unsigned int readableBytes( void );
	bool readBuffer( int bytes );
	int audio_fd;

	void mono_to_stereo(void *b_from, void *b_to, size_t count);//!
	void stereo_to_mono(void *b_from, void *b_to, size_t count);//!
	void scale_mono_input(void *b_to, size_t count, double& vol, int& changed, double& maxvol);//!

private:
	AudioBuffer output_buf;   // Output buffer
	QString filename;         // device filename
	bool audio_stereo;

signals://!
	void microVolUpdated();//!
	void speakerVolUpdated();//!
	void microSigUpdated( double );//!
	void speakerSigUpdated( double );//!
};

#endif  // DSPOUTOSS_H_INCLUDED
